﻿$v2rayPID = Get-Process -name v2ray -ErrorAction Ignore | Select-Object id | ForEach-Object -Process { $_.id }
$wv2rayPID = Get-Process -name wv2ray -ErrorAction Ignore | Select-Object id | ForEach-Object -Process { $_.id }
$v2rayInstallPath = "$env:SystemDrive" + "\tools" + "\v2ray"
$temp = "$env:TEMP"
$urlia32 = "https://github.com/v2fly/v2ray-core/releases/download/v4.44.0/v2ray-windows-32.zip"
$urlarm64 = "https://github.com/v2fly/v2ray-core/releases/download/v4.44.0/v2ray-windows-arm64-v8a.zip"
$url64 = "https://github.com/v2fly/v2ray-core/releases/download/v4.44.0/v2ray-windows-64.zip"
$SHA256_ia32 = "40bb05746b2931679311833ab3dd8db2a5c03c672b9e12d5ba2c90f6031122ff"
$SHA256_arm64 = "65e3960a1c1099dbee321a8a1d541b341842b470a9bea315e6e142f6f4bee5f1"
$SHA256_64 = "c3d04d4c3c8ec7513ac0079138a8278f6517f86af34894e80aa4f1f0f5d05ad4"

# Check the device, is it an ARM-based one?
$CheckARM = Get-WmiObject win32_processor | Select-Object Caption | Select-String ARM

if ([String]::IsNullOrEmpty($CheckARM)) {
    $url = $urlia32; $SHA256_32 = $SHA256_ia32
}
else {
    Write-Output "You have an ARM-based Windows device, it is going to install armv7(AArch32) version for you.";
    $url = $urlarm64; $SHA256_32 = $SHA256_arm64
}

# Download and installation
Get-ChocolateyWebFile -PackageName "v2ray.zip" -FileFullPath "$temp\v2ray.zip"  -Url $url  -Checksum $SHA256_32 -ChecksumType 'sha256' -Url64 $url64  -Checksum64 $SHA256_64  -ChecksumType64 'sha256'
if ([String]::IsNullOrEmpty($v2rayPID)) {
    Write-Output "Process v2ray.exe is not running."
} 
else {
    Write-Output "Process v2ray.exe is running, stop it and install a new version."; Stop-Process $v2rayPID
}
if ([String]::IsNullOrEmpty($wv2rayPID)) {
    Write-Output "Process wv2ray.exe is not running."
} 
else {
    Write-Output "Process wv2ray.exe is running, stop it and install a new version."; Stop-Process $wv2rayPID
}
Install-ChocolateyZipPackage -PackageName 'v2ray'  -UnzipLocation $v2rayInstallPath -File $temp\v2ray.zip  -File64 $temp\v2ray.zip 
Install-ChocolateyPath -PathToInstall $v2rayInstallPath -PathType 'Machine'
Write-Output "V2Ray Core has been installed / updated, you can use it now."